[evolution] Bug 571723 - Prefer "Cancelled" over "Canceled" in translatable strings



commit cc8a823062bd579888077cb0e4481c9d92d4add6
Author: Milan Crha <mcrha redhat com>
Date:   Wed May 11 20:34:32 2016 +0200

    Bug 571723 - Prefer "Cancelled" over "Canceled" in translatable strings

 calendar/gui/e-cal-component-preview.c         |    2 +-
 calendar/gui/e-cal-model-tasks.c               |    4 ++--
 calendar/gui/e-comp-editor-property-parts.c    |    2 +-
 calendar/gui/e-task-table.c                    |    6 +++---
 calendar/gui/print.c                           |    2 +-
 libemail-engine/mail-ops.c                     |    2 +-
 mail/mail-send-recv.c                          |    2 +-
 modules/backup-restore/evolution-backup-tool.c |    4 ++--
 modules/itip-formatter/itip-view.c             |   14 +++++++-------
 9 files changed, 19 insertions(+), 19 deletions(-)
---
diff --git a/calendar/gui/e-cal-component-preview.c b/calendar/gui/e-cal-component-preview.c
index 07a1d44..1653819 100644
--- a/calendar/gui/e-cal-component-preview.c
+++ b/calendar/gui/e-cal-component-preview.c
@@ -305,7 +305,7 @@ cal_component_preview_write_html (ECalComponentPreview *preview,
                        str = g_strdup (_("Completed"));
                        break;
                case ICAL_STATUS_CANCELLED :
-                       str = g_strdup (_("Canceled"));
+                       str = g_strdup (_("Cancelled"));
                        break;
                case ICAL_STATUS_NONE :
                default :
diff --git a/calendar/gui/e-cal-model-tasks.c b/calendar/gui/e-cal-model-tasks.c
index fee0e40..c0649ec 100644
--- a/calendar/gui/e-cal-model-tasks.c
+++ b/calendar/gui/e-cal-model-tasks.c
@@ -313,7 +313,7 @@ get_status (ECalModelComponent *comp_data)
                case ICAL_STATUS_COMPLETED:
                        return (gpointer) _("Completed");
                case ICAL_STATUS_CANCELLED:
-                       return (gpointer) _("Canceled");
+                       return (gpointer) _("Cancelled");
                default:
                        return (gpointer) "";
                }
@@ -555,7 +555,7 @@ set_status (ECalModelComponent *comp_data,
                status = ICAL_STATUS_INPROCESS;
        else if (!e_util_utf8_strcasecmp (value, _("Completed")))
                status = ICAL_STATUS_COMPLETED;
-       else if (!e_util_utf8_strcasecmp (value, _("Canceled")))
+       else if (!e_util_utf8_strcasecmp (value, _("Cancelled")))
                status = ICAL_STATUS_CANCELLED;
        else {
                g_warning ("Invalid status: %s\n", value);
diff --git a/calendar/gui/e-comp-editor-property-parts.c b/calendar/gui/e-comp-editor-property-parts.c
index 53ebeb6..066b738 100644
--- a/calendar/gui/e-comp-editor-property-parts.c
+++ b/calendar/gui/e-comp-editor-property-parts.c
@@ -1170,7 +1170,7 @@ e_comp_editor_property_part_status_new (void)
                { ICAL_STATUS_NONE,      NC_("ECompEditor", "Not Started"), TRUE,  NULL },
                { ICAL_STATUS_INPROCESS, NC_("ECompEditor", "In Progress"), FALSE, NULL },
                { ICAL_STATUS_COMPLETED, NC_("ECompEditor", "Completed"),   FALSE, NULL },
-               { ICAL_STATUS_CANCELLED, NC_("ECompEditor", "Canceled"),    FALSE, NULL }
+               { ICAL_STATUS_CANCELLED, NC_("ECompEditor", "Cancelled"),    FALSE, NULL }
        };
        gint ii, n_elems = G_N_ELEMENTS (map);
 
diff --git a/calendar/gui/e-task-table.c b/calendar/gui/e-task-table.c
index e6e06aa..b085bfd 100644
--- a/calendar/gui/e-task-table.c
+++ b/calendar/gui/e-task-table.c
@@ -210,7 +210,7 @@ task_table_status_compare_cb (gconstpointer a,
                        status_a = 1;
                else if (same_cache_string (cmp_cache, cache_str, _("Completed")))
                        status_a = 2;
-               else if (same_cache_string (cmp_cache, cache_str, _("Canceled")))
+               else if (same_cache_string (cmp_cache, cache_str, _("Cancelled")))
                        status_a = 3;
        }
 
@@ -225,7 +225,7 @@ task_table_status_compare_cb (gconstpointer a,
                        status_b = 1;
                else if (same_cache_string (cmp_cache, cache_str, _("Completed")))
                        status_b = 2;
-               else if (same_cache_string (cmp_cache, cache_str, _("Canceled")))
+               else if (same_cache_string (cmp_cache, cache_str, _("Cancelled")))
                        status_b = 3;
        }
 
@@ -607,7 +607,7 @@ task_table_constructed (GObject *object)
        strings = g_list_append (strings, (gchar *) _("Not Started"));
        strings = g_list_append (strings, (gchar *) _("In Progress"));
        strings = g_list_append (strings, (gchar *) _("Completed"));
-       strings = g_list_append (strings, (gchar *) _("Canceled"));
+       strings = g_list_append (strings, (gchar *) _("Cancelled"));
        e_cell_combo_set_popdown_strings (
                E_CELL_COMBO (popup_cell),
                strings);
diff --git a/calendar/gui/print.c b/calendar/gui/print.c
index fa4034c..dac6bdb 100644
--- a/calendar/gui/print.c
+++ b/calendar/gui/print.c
@@ -3585,7 +3585,7 @@ print_comp_draw_real (GtkPrintOperation *operation,
                                status_string = _("Completed");
                                break;
                        case ICAL_STATUS_CANCELLED:
-                               status_string = _("Canceled");
+                               status_string = _("Cancelled");
                                break;
                        default:
                                break;
diff --git a/libemail-engine/mail-ops.c b/libemail-engine/mail-ops.c
index fe80865..b930434 100644
--- a/libemail-engine/mail-ops.c
+++ b/libemail-engine/mail-ops.c
@@ -1061,7 +1061,7 @@ send_queue_exec (struct _send_queue_msg *m,
                        j, send_uids->len);
        else if (g_error_matches (
                        m->base.error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-               report_status (m, CAMEL_FILTER_STATUS_END, 100, _("Canceled."));
+               report_status (m, CAMEL_FILTER_STATUS_END, 100, _("Cancelled."));
        else
                report_status (m, CAMEL_FILTER_STATUS_END, 100, _("Complete."));
 
diff --git a/mail/mail-send-recv.c b/mail/mail-send-recv.c
index 68f5a9a..5bbcfc5 100644
--- a/mail/mail-send-recv.c
+++ b/mail/mail-send-recv.c
@@ -961,7 +961,7 @@ receive_done (gpointer data)
                        GTK_PROGRESS_BAR (info->progress_bar), 1.0);
 
                if (info->state == SEND_CANCELLED)
-                       text = _("Canceled");
+                       text = _("Cancelled");
                else {
                        text = _("Complete");
                        info->state = SEND_COMPLETE;
diff --git a/modules/itip-formatter/itip-view.c b/modules/itip-formatter/itip-view.c
index bf80704..6a80b1d 100644
--- a/modules/itip-formatter/itip-view.c
+++ b/modules/itip-formatter/itip-view.c
@@ -439,9 +439,9 @@ set_calendar_sender_text (ItipView *view)
                break;
        case ITIP_VIEW_MODE_CANCEL:
                if (priv->organizer_sentby)
-                       sender = dupe_first_bold (_("%s through %s has canceled the following meeting:"), 
organizer, priv->organizer_sentby);
+                       sender = dupe_first_bold (_("%s through %s has cancelled the following meeting:"), 
organizer, priv->organizer_sentby);
                else
-                       sender = dupe_first_bold (_("%s has canceled the following meeting:"), organizer, 
NULL);
+                       sender = dupe_first_bold (_("%s has cancelled the following meeting:"), organizer, 
NULL);
                break;
        case ITIP_VIEW_MODE_COUNTER:
                if (priv->attendee_sentby)
@@ -529,9 +529,9 @@ set_tasklist_sender_text (ItipView *view)
                break;
        case ITIP_VIEW_MODE_CANCEL:
                if (priv->organizer_sentby)
-                       sender = dupe_first_bold (_("%s through %s has canceled the following assigned 
task:"), organizer, priv->organizer_sentby);
+                       sender = dupe_first_bold (_("%s through %s has cancelled the following assigned 
task:"), organizer, priv->organizer_sentby);
                else
-                       sender = dupe_first_bold (_("%s has canceled the following assigned task:"), 
organizer, NULL);
+                       sender = dupe_first_bold (_("%s has cancelled the following assigned task:"), 
organizer, NULL);
                break;
        case ITIP_VIEW_MODE_COUNTER:
                if (priv->attendee_sentby)
@@ -595,9 +595,9 @@ set_journal_sender_text (ItipView *view)
                break;
        case ITIP_VIEW_MODE_CANCEL:
                if (priv->organizer_sentby)
-                       sender = dupe_first_bold (_("%s through %s has canceled the following shared memo:"), 
organizer, priv->organizer_sentby);
+                       sender = dupe_first_bold (_("%s through %s has cancelled the following shared 
memo:"), organizer, priv->organizer_sentby);
                else
-                       sender = dupe_first_bold (_("%s has canceled the following shared memo:"), organizer, 
NULL);
+                       sender = dupe_first_bold (_("%s has cancelled the following shared memo:"), 
organizer, NULL);
                break;
        default:
                break;
@@ -4816,7 +4816,7 @@ receive_objects_ready_cb (GObject *ecalclient,
                /* FIXME some calendars just might not save it at all, is this accurate? */
                itip_view_add_lower_info_item_printf (
                        view, ITIP_VIEW_INFO_ITEM_TYPE_INFO,
-                       _("Sent to calendar '%s' as canceled"), e_source_get_display_name (source));
+                       _("Sent to calendar '%s' as cancelled"), e_source_get_display_name (source));
                break;
        default:
                g_warn_if_reached ();


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/modules/backup-restore/evolution-backup-tool.c b/modules/backup-restore/evolution-backup-tool.c
index a288ce6..e0ed680 100644
--- a/modules/backup-restore/evolution-backup-tool.c
+++ b/modules/backup-restore/evolution-backup-tool.c
@@ -814,11 +814,11 @@ dlg_response (GtkWidget *dlg,
        run_cmd ("pkill tar");
 
        if (bk_file && backup_op && response == GTK_RESPONSE_REJECT) {
                /* Backup was canceled, delete the
                 * backup file as it is not needed now. */
                gchar *cmd, *filename;
 
-               g_message ("Back up canceled, removing partial back up file.");
+               g_message ("Back up cancelled, removing partial back up file.");
 
                filename = g_shell_quote (bk_file);
                cmd = g_strconcat ("rm ", filename, NULL);
@@ -814,11 +814,11 @@ dlg_response (GtkWidget *dlg,
 
        if (bk_file && backup_op && response == GTK_RESPONSE_REJECT) {
-               /* Backup was canceled, delete the
+               /* Backup was cancelled, delete the
                 * backup file as it is not needed now. */
                gchar *cmd, *filename;